# CMake file
# Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2012
# Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2012
#
# See the file LICENSE.txt in the package base directory for details
#
# @file FindGTI.cmake
#       Detects the GTI installation.
#
# @author Tobias Hilbrich
# @date 03.01.2011

SET(PnMPI_FOUND FALSE)

IF (NOT PnMPI_INSTALL_PREFIX)

    file(TO_CMAKE_PATH "$ENV{PATH}" envpath)

    FIND_PROGRAM (PnMPI_PATCHER NAMES pnmpi-patch PATH envpath)

    string(REGEX REPLACE "/bin/pnmpi-patch"
            "" PnMPI_INSTALL_PREFIX
            ${PnMPI_PATCHER})

ENDIF (NOT PnMPI_INSTALL_PREFIX)


SET (PnMPI_HOME "${PnMPI_INSTALL_PREFIX}" CACHE PATH "PnMPI installation directory." FORCE)

IF (EXISTS "${PnMPI_HOME}/share/cmake/PnMPI/PnMPIConfig.cmake")
    #Was found
    SET(PnMPI_FOUND TRUE)
    
    #Add the helper modules from PnMPI, and the installation configuration of it
    SET(CMAKE_MODULE_PATH "${PnMPI_HOME}/share/cmake/PnMPI;${CMAKE_MODULE_PATH}")
    INCLUDE (PnMPIConfig)
    
    #Fix for frontend built patcher in PnMPI
    get_target_property(PNMPI_PATCHER_LOCATION pnmpi-patch LOCATION)
    IF (NOT PNMPI_PATCHER_LOCATION)
        SET_PROPERTY (TARGET pnmpi-patch APPEND PROPERTY IMPORTED_CONFIGURATIONS UNKNOWNCONFIG)
        SET_TARGET_PROPERTIES(pnmpi-patch PROPERTIES
          IMPORTED_LOCATION_UNKNOWNCONFIG "${PnMPI_HOME}/bin/pnmpi-patch"
          )        
    ENDIF ()
    
 ELSE (EXISTS "${PnMPI_HOME}/share/cmake/PnMPI/PnMPIConfig.cmake")
    #Was not found
    IF (PnMPI_FIND_REQUIRED)
        MESSAGE (FATAL_ERROR "PnMPI installation was not found, please specify PnMPI_HOME.")
    ELSE ()
        MESSAGE ("PnMPI installation was not found, please specify PnMPI_HOME.")
    ENDIF ()
ENDIF (EXISTS "${PnMPI_HOME}/share/cmake/PnMPI/PnMPIConfig.cmake")
