/*
 * GTI (Generic Tools Infrastructure)
 * Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2012
 * Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2012
 *
 * See the file LICENSE.txt in the package base directory for details
 */

/**
 * @file BaseApi.h
 * 		P call definition for implicitly added GTI API.
 *
 * @author Tobias Hilbrich
 * @date 27.06.2012
 */

#ifndef GTI_API_H
#define GTI_API_H

/**
 * API event for notifying all layers of a shutdown
 */
inline int PgtiShutdownNotify (void) {return 0;}
typedef int (*gtiShutdownNotifyP) (void);

/**
 * API event for raising a panic.
 *
 * Description:
 * All TBON nodes can create this event in order to raise a panic, i.e.,
 * an ongoing application crash. It causes ALL TBON nodes to:
 * a) Flush outstanding communications
 * b) Deactivate potentially existent event aggregation (I.e., all successive sends will be immediate)
  */
inline int PgtiRaisePanic (void) {return 0;}
typedef int (*gtiRaisePanicP) (void);

/**
 * API event for notifying all TBON nodes of an ongoing panic.
 *
 * Description:
 * Created by GTI internaly, should not be created by the user!
 * Is triggered and broadcasted to all TBON nodes if at least one
 * gtiRaisePanic event was created on some TBON node.
 */
inline int PgtiNotifyPanic (void) {return 0;}
typedef int (*gtiNotifyPanicP) (void);

/**
 * API event for notifying all TBON nodes of a request to flush their
 * outstanding events.
 *
 * Description:
 * Can be created on any TBON node, can be called by any user module.
 * Causes the sub-tree connected to the current TBON node to flush all
 * outstanding upwards and intra-layer communication. Successive aggregation
 * after this event arrives on some node is allowed.
 */
inline int PgtiNotifyFlush (void) {return 0;}
typedef int (*gtiNotifyFlushP) (void);

#endif /*GTI_API_H*/
